@@ -7,5 +7,5 @@ mod tests {
 }
 
 pub fn say_hello() -> () {
-    println!("hello from halima");
+    println!("hello from halima v2");
 }
